@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-present Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -82,7 +82,7 @@ class AppKit_DataProvider_UserProviderAction extends AppKitBaseAction {
             $userObject["roles"][] = array(
                 "id" => $role->role_id,
                 "name" => $role->role_name,
-                "description" => $role->role_name,
+                "description" => $role->role_description,
                 "active" => $role->role_disabled != 1
             );
         }
