@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-present Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -147,7 +147,7 @@ class AppKit_Auth_DispatchModel extends AppKitBaseModel implements AgaviISinglet
             $this->log('Auth.Dispatch: Converting username to lowercase', AgaviLogger::INFO);
             $username = strtolower($username);
         }
-        
+
         $success = false;
 
         $user = $this->findUser($username);
@@ -379,7 +379,11 @@ class AppKit_Auth_DispatchModel extends AppKitBaseModel implements AgaviISinglet
         }
 
         // check if the name is an auth_key
-        $user = Doctrine::getTable('NsmUser')->findBySql('user_authkey=?', array($username));
+        if ($this->getParameter('auth_lowercase_username', false) == true) {
+            $user = Doctrine::getTable('NsmUser')->findBySql('lower(user_authkey)=?', array($username));
+        } else {
+            $user = Doctrine::getTable('NsmUser')->findBySql('user_authkey=?', array($username));
+        }
 
         if ($user->count() == 1) {
             return $user->getFirst();
